@@ -29,6 +29,6 @@ void set_form(reference *ref, struct curl_httppost* newform);
 void set_headers(reference *ref, struct curl_slist *newheaders);
 void reset_resheaders(reference *ref);
 void clean_handle(reference *ref);
-int pending_interrupt();
 size_t push_disk(void* contents, size_t sz, size_t nmemb, FILE *ctx);
 size_t append_buffer(void *contents, size_t sz, size_t nmemb, void *ctx);
+CURLcode curl_perform_with_interrupt(CURL *handle);
